@@ -4,12 +4,20 @@ use twilight_model::{
     id::{GuildId, UserId},
 };
 
+/// Represents a cached [`Presence`].
+///
+/// [`Presence`]: twilight_model::gateway::presence::Presence
 #[derive(Clone, Debug, Eq, PartialEq, Serialize)]
 pub struct CachedPresence {
+    /// Current activities.
     pub activities: Vec<Activity>,
+    /// Platform-dependent status.
     pub client_status: ClientStatus,
+    /// ID of the guild.
     pub guild_id: GuildId,
+    /// Status of the user.
     pub status: Status,
+    /// ID of the user.
     pub user_id: UserId,
 }
 
@@ -31,11 +39,11 @@ impl PartialEq<Presence> for CachedPresence {
     }
 }
 
-impl From<&'_ Presence> for CachedPresence {
-    fn from(presence: &'_ Presence) -> Self {
+impl From<Presence> for CachedPresence {
+    fn from(presence: Presence) -> Self {
         Self {
-            activities: presence.activities.clone(),
-            client_status: presence.client_status.clone(),
+            activities: presence.activities,
+            client_status: presence.client_status,
             guild_id: presence.guild_id,
             status: presence.status,
             user_id: presence_user_id(&presence.user),
